@@ -7,15 +7,16 @@
 [![npm](https://img.shields.io/npm/dw/cdk-ecr-deployment?label=npm%20downloads)](https://www.npmjs.com/package/cdk-ecr-deployment)
 [![PyPI - Downloads](https://img.shields.io/pypi/dw/cdk-ecr-deployment?label=pypi%20downloads)](https://pypi.org/project/cdk-ecr-deployment)
 
-CDK construct to deploy docker image to Amazon ECR
+CDK construct to synchronize single docker image between docker registries.
 
 ⚠️ Please use ^1.0.0 for cdk version 1.x.x, use ^2.0.0 for cdk version 2.x.x
 
 ## Features
 
-* Copy an ECR image to another
-* Copy docker hub image to ECR
-* Copy an archive tarball image from s3 to ECR
+* Copy image from ECR/external registry to (another) ECR/external registry
+* Copy an archive tarball image from s3 to ECR/external registry
+
+⚠️ Currently construct can authenticate to external registry only with basic auth, but credentials are put as plain text to template and logs. See issue [#171](https://github.com/cdklabs/cdk-ecr-deployment/issues/171).
 
 ## Examples
 
@@ -27,7 +28,7 @@ NO_PREBUILT_LAMBDA=1 npx cdk deploy -a "npx ts-node -P tsconfig.dev.json --prefe
 
 ## Tech Details & Contribution
 
-The core of this project relies on https://github.com/containers/image which is used by https://github.com/containers/skopeo.
+The core of this project relies on [containers/image](https://github.com/containers/image) which is used by [Skopeo](https://github.com/containers/skopeo).
 Please take a look at those projects before contribution.
 
 To support a new docker image source(like docker tarball in s3), you need to implement [image transport interface](https://github.com/containers/image/blob/master/types/types.go). You could take a look at [docker-archive](https://github.com/containers/image/blob/ccb87a8d0f45cf28846e307eb0ec2b9d38a458c2/docker/archive/transport.go) transport for a good start.
@@ -63,6 +64,7 @@ class ECRDeployment(
         *,
         dest: "IImageName",
         src: "IImageName",
+        build_image: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
@@ -74,6 +76,7 @@ class ECRDeployment(
         :param id: -
         :param dest: The destination of the docker image.
         :param src: The source of the docker image.
+        :param build_image: Image to use to build Golang lambda for custom resource, if download fails or is not wanted. Might be needed for local build if all images need to come from own registry. Note that image should use yum as a package manager and have golang available. Default: public.ecr.aws/sam/build-go1.x:latest
         :param environment: The environment variable to set.
         :param memory_limit: The amount of memory (in MiB) to allocate to the AWS Lambda function which replicates the files from the CDK bucket to the destination bucket. If you are deploying large files, you will need to increase this number accordingly. Default: 512
         :param role: Execution role associated with this function. Default: - A role is automatically created
@@ -83,6 +86,7 @@ class ECRDeployment(
         props = ECRDeploymentProps(
             dest=dest,
             src=src,
+            build_image=build_image,
             environment=environment,
             memory_limit=memory_limit,
             role=role,
@@ -99,6 +103,7 @@ class ECRDeployment(
     name_mapping={
         "dest": "dest",
         "src": "src",
+        "build_image": "buildImage",
         "environment": "environment",
         "memory_limit": "memoryLimit",
         "role": "role",
@@ -112,6 +117,7 @@ class ECRDeploymentProps:
         *,
         dest: "IImageName",
         src: "IImageName",
+        build_image: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
@@ -121,6 +127,7 @@ class ECRDeploymentProps:
         '''
         :param dest: The destination of the docker image.
         :param src: The source of the docker image.
+        :param build_image: Image to use to build Golang lambda for custom resource, if download fails or is not wanted. Might be needed for local build if all images need to come from own registry. Note that image should use yum as a package manager and have golang available. Default: public.ecr.aws/sam/build-go1.x:latest
         :param environment: The environment variable to set.
         :param memory_limit: The amount of memory (in MiB) to allocate to the AWS Lambda function which replicates the files from the CDK bucket to the destination bucket. If you are deploying large files, you will need to increase this number accordingly. Default: 512
         :param role: Execution role associated with this function. Default: - A role is automatically created
@@ -133,6 +140,8 @@ class ECRDeploymentProps:
             "dest": dest,
             "src": src,
         }
+        if build_image is not None:
+            self._values["build_image"] = build_image
         if environment is not None:
             self._values["environment"] = environment
         if memory_limit is not None:
@@ -158,6 +167,19 @@ class ECRDeploymentProps:
         assert result is not None, "Required property 'src' is missing"
         return typing.cast("IImageName", result)
 
+    @builtins.property
+    def build_image(self) -> typing.Optional[builtins.str]:
+        '''Image to use to build Golang lambda for custom resource, if download fails or is not wanted.
+
+        Might be needed for local build if all images need to come from own registry.
+
+        Note that image should use yum as a package manager and have golang available.
+
+        :default: public.ecr.aws/sam/build-go1.x:latest
+        '''
+        result = self._values.get("build_image")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def environment(
         self,
